@@ -2,7 +2,7 @@
 #define __HIREDIS_PY_H
 
 #include <Python.h>
-#include <hiredis/hiredis.h>
+#include <hiredis/read.h>
 
 #ifndef PyMODINIT_FUNC	/* declarations for DLL import/export */
 #define PyMODINIT_FUNC void
